@@ -171,12 +171,6 @@ indent_print <- function(..., .indent = " ", .printer = print) {
   invisible(list(...)[[1]])
 }
 
-#' Better printing of R packages
-#'
-#' @docType package
-#' @name printr
-NULL
-
 add_class <- function(x, class) {
 
   if (!inherits(x, class)) {
