@@ -21,3 +21,9 @@
 
 */
 
+#include "uuid/uuid.h"
+
+#define R_IGRAPH_TYPE_VERSION "0.8.0"
+#define R_IGRAPH_VERSION_VAR ".__igraph_version__."
+
+SEXP R_igraph_add_env(SEXP graph);
