@@ -3,6 +3,7 @@ context("Seeded graph matching")
 
 test_that("SGM works", {
   library(igraph)
+  local_rng_version("3.5.0")
   set.seed(42)
 
   vc <- 10
@@ -32,7 +33,7 @@ test_that("SGM works", {
   P <- match_vertices(g1[], g2[], m=nos, start=matrix(1/(vc-nos), vc-nos, vc-nos),
            iteration=20)
 
-  test_that(P$corr[,2], equals(perm[(nos+1):vc]))
+  expect_that(P$corr[,2], equals(perm[(nos+1):vc]))
   expect_that(apply(P$P != 0, 1, which), equals(perm))
   expect_that(apply(P$D != 0, 1, which),
               equals(perm[(nos+1):vc] - nos))
